import sys 
import jarray
from java.io import BufferedWriter
from java.io import File
from java.io import FileInputStream
from java.io import FileOutputStream
from java.io import OutputStreamWriter
from java.lang import String
from java.util import Vector
from java.util.zip import ZipEntry
from java.util.zip import ZipOutputStream

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split(" ")
        else:
                tmpList = inStr.split("\n")  #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();        #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef
errorCode = ""
errorInfo = ""

# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2005, 2006. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT
#
#  Common Procedures for Export Artifacts Scripts
#
#  The following global constants and variables have to be declared and set in the scripts that include these common procedures:
#    
#    Error codes:
#    	COMPONENT_NOT_FOUND                 
#    	ARTIFACTS_NOT_FOUND  
#    Component substitution text:
#    	COMPONENT  {name of exported component}
#    Internal switches:
#    	debugOutFlag {1 = full debug trace output; 
#                     0 = no sysout output unless error and nlsEnabledFlag is off}
#
#       nlsEnabledFlag {1 = NLS enabled, default, requires customization.jar to be present in <washome>\lib;
#                       0 = sysout will be used for errors}
#
#----------------------------------------------------------------------------------------------------------

global env
importArtifactsProcFilePath = java.lang.System.getProperty("was.install.root") + "/bin/importArtifactsProc.py"
execfile(importArtifactsProcFilePath)

#-------------------------------------------------------------
#-- Proc: exportArtifacts
#
# Exports artifacts for components specified in the component
# ID list to the specified ZIP file. 
# Params:
#   mBeanObj          - pointer to MBean object
#   componentIdList   - list of selector component ID objects
#   usrdId            - user 
#   exportZipF        - export ZIP file
# 
#------------------------------------------------------------

def exportArtifacts ( mBeanObj, componentIdList, userId, exportZipf ):

        global AdminControl
        global COMPONENT_NOT_FOUND
        global ARTIFACTS_NOT_FOUND
        global COMPONENT

        msg = "****---> exportArtifacts " + mBeanObj.toString() + " " + componentIdList.toString() + " " + userId + " " + exportZipf
        debugOut(msg)

        userIdStr = String( userId )

        parms = jarray.array([userIdStr, componentIdList], java.lang.Object) 

        signature = jarray.array(["java.lang.String", "java.util.List"], java.lang.String) 

        # get list of components each with a list of its artifacts 
        try:
                _excp_ = 0
                componentList = AdminControl.invoke_jmx(mBeanObj, "getExportableArtifactsForComponents", parms, signature )
                result = componentList
                _excp_ = 0 #reset (in case of nested exceptions)
        except:
                _type_, _value_, _tbck_ = sys.exc_info()
                result = str(_value_)
                _excp_ = 1
        #endTry 
        if (_excp_ ):
                exceptionExit(result )
        else:
                msg = "Returned %i components" % (componentList.size())
                debugOut(msg)
                _J2J_bracket_ = componentList.size()
                if (_J2J_bracket_ > 0):
                        fileList = Vector(  ) 
                        it = componentList.iterator()
                        while (it.hasNext()):
                                component = it.next()
                                artifactList = component.getExportableArtifacts()
                                msg = "Returned %i artifacts" % (artifactList.size())
                                debugOut(msg)
                                _J2J_bracket_ = artifactList.size()
                                if (_J2J_bracket_ > 0):
                                        it2 = artifactList.iterator()
                                        # write each artifact to a temporary file
                                        while (it2.hasNext()):
                                                artifact = it2.next()
                                                fileList.add(writeArtifactToFile(artifact))
                                        #endWhile 
                                else:
                                        debugOut("Error -- No artifacts found." )
                                        errorExit(ARTIFACTS_NOT_FOUND )
                                #endElse 
                        #endWhile 
                        # zip content of temporary artifact files to the zip file provided
                        zipArtifactFiles(fileList, exportZipf )
                else:
                        debugOut("Error -- "+COMPONENT+" not found." )
                        errorExit(COMPONENT_NOT_FOUND )
                #endElse 
        #endElse 
        debugOut("****<--- exportArtifacts" )
        return 
#endDef 

#-------------------------------------------------------------------
#-- Proc: writeArtifactToFile
#
# The procedure writes the artifact to a temporary file
#  
# params:
#   artifact   -  Artifact to be exported 
#
# Returns: 
#   tempPath   -  Path of the temporary file to which the artifact has been written 
# 
# -------------------------------------------------------------------  
def writeArtifactToFile ( artifact ):

        debugOut("*****---> writeArtifactToFile ["+artifact.toString()+" getRelativeFileName]" )

        content = artifact.getContents()
        fileName = artifact.getRelativeFileName()
        debugOut("Relative file name: "+fileName )
        debugOut(content )

        tempFile = File( fileName ) 
        parentFile = tempFile.getParentFile()

        null =  None 
        if (parentFile != null):
                createDirs = parentFile.mkdirs()
        #endIf 
        absFile = tempFile.getAbsolutePath()
        debugOut("Absolute file path: "+absFile )

        # Use buffering.  Make sure to specify a UTF-8 character encoding to
        # handle non-ASCII characters.
        charEncoding = "utf-8"
        output = BufferedWriter( OutputStreamWriter( FileOutputStream( absFile ), charEncoding ) )
        contentLength = String(artifact.getContents()).length()
        output.write( content, 0, contentLength )
        if (output != null):
                output.close()
        #endIf 

        tempPath = tempFile.getPath()
        debugOut("*****<--- writeArtifactToFile "+tempPath )
        return tempPath
#endDef 

#-------------------------------------------------------------------
#-- Proc: zipArtifactFiles
#
# The procedure zips the content of temporary artifact files to the 
# supplied ZIP file and deletes the temporary files 
#  
# Params:
#   fileList        List of artifact files to zip 
#   exportZipf      Name of the zip file 
#
# Returns: 
#
# 
# -------------------------------------------------------------------  
def zipArtifactFiles ( fileList, exportZipf ):
        debugOut("*****---> zipArtifactFiles "+fileList.toString()+" "+exportZipf )

        buf = jarray.zeros(1024, "b") 
        diskFile = File( exportZipf ) 
        outFileName = diskFile.getPath()
        debugOut("Outfile name: "+outFileName )

        try:
                _excp_ = 0
                out = ZipOutputStream( FileOutputStream( outFileName ) ) 
                result = out
                _excp_ = 0 #reset (in case of nested exceptions)
        except:
                _type_, _value_, _tbck_ = sys.exc_info()
                result = str(_value_)
                _excp_ = 1
        #endTry 
        if (_excp_ ):
                # cover for java.io.FileNotFoundException when parent directory not found 
                parentFile = diskFile.getParentFile()
                null =  None 
                if (parentFile != null):
                        createDirs = parentFile.mkdirs( )
                #endIf 
                # it must be something else which causes the exception 
                try:
                        _excp_ = 0
                        out = ZipOutputStream( FileOutputStream( outFileName ) ) 
                        result = _J2J_bracket_
                        _excp_ = 0 #reset (in case of nested exceptions)
                except:
                        _type_, _value_, _tbck_ = sys.exc_info()
                        result = str(_value_)
                        _excp_ = 1
                #endTry 
                if (_excp_ ):
                        exceptionExit(result )
                #endIf 
        #endIf 
        for i in range(fileList.size()):
            elem = fileList.elementAt(i);
            debugOut("File list element: "+elem )

            fIS = FileInputStream( elem ) 
            out.putNextEntry(ZipEntry( elem ) )
            len = fIS.read( buf )
            while (len > 0):
                out.write(buf, 0, len)
                len = fIS.read( buf )
            #endWhile 
            out.closeEntry()
            fIS.close()
            fileToDelete = File( elem ) 
            debugOut("Delete " + fileToDelete.toString())
            fileToDelete.delete()
        out.close()
        debugOut("*****<--- zipArtifactFiles" )
#endDef 
